@@ -26,6 +26,7 @@ import plotext as plt
 import pint_pandas
 import radboy.DB.ExerciseTracker as ET
 import zipfile
+from copy import copy
 
 class HealthLogUi:
 	def edit_hlid(self):
@@ -532,7 +533,8 @@ class HealthLogUi:
 				return True
 
 
-	def showAllField(self,fields=[],not_none=[]):
+	def showAllField(self,fields=[],not_none=[],total_drg=True,total_fd=False):
+		unit_registry=pint.UnitRegistry()
 		try:
 			useDateRange=Prompt.__init2__(None,func=FormBuilderMkText,ptext="use a date range?",helpText="yes or no",data="boolean")
 			if useDateRange is None:
@@ -581,9 +583,29 @@ class HealthLogUi:
 					if x is None:
 						return
 				
+				if total_drg or total_fd:
+					dummy={}
+
 				results=results.all()
 				ct=len(results)
 				for num,i in enumerate(results):
+					if total_drg or total_fd:
+						if total_drg:
+							if i.DrugConsumed in dummy:
+								try:
+									#normalize the values first
+									old=unit_registry.Quantity(dummy[i.DrugConsumed].DrugQtyConsumed,dummy[i.DrugConsumed].DrugQtyConsumedUnitName)
+									new=unit_registry.Quantity(i.DrugQtyConsumed,i.DrugQtyConsumedUnitName)
+									f=old+new
+									dummy[i.DrugConsumed].DrugQtyConsumed=f.magnitude
+									dummy[i.DrugConsumed].DrugQtyConsumedUnitName=f.units
+								except Exception as e:
+									print(e,"processing will not include this value")
+							else:
+								dummy[i.DrugConsumed]=copy(i)
+						if total_fd:
+							pass
+							
 					view=[]
 					for x in fields:
 						if getattr(i,str(x.name)) == None:
@@ -595,6 +617,22 @@ class HealthLogUi:
 						view.append(f'{color_date}{Style.bold}{str(x.name)}{Fore.deep_sky_blue_1}={color}{str(getattr(i,str(x.name)))}{Style.reset}')
 					msg=f"{Fore.light_green}{num}{Fore.light_yellow}/{num+1} of {Fore.light_red}{ct} ->{'|'.join(view)}"
 					print(msg)
+				if total_drg or total_fd:
+					print(f"{Fore.orange_red_1}Broken into Totals{Style.reset}")
+					ct=len(dummy)
+					view=[]
+					for num,i in enumerate(dummy):
+						i=dummy[i]
+						for x in fields:
+							if getattr(i,str(x.name)) == None:
+								color=f"{Fore.grey_15}"
+								color_date=f"{Fore.grey_15}"
+							else:
+								color=f"{Fore.sea_green_2}"
+								color_date=f"{Fore.green_3b}"
+							view.append(f'{color_date}{Style.bold}{str(x.name)}{Fore.deep_sky_blue_1}={color}{str(getattr(i,str(x.name)))}{Style.reset}')
+					msg=f"{Fore.light_green}{num}{Fore.light_yellow}/{num+1} of {Fore.light_red}{ct} ->{'|'.join(view)}"
+					print(msg)
 		except Exception as e:
 			print(e)
 
